======================
Differential Operators
======================

.. autoclass:: findiff.Diff
    :members:
    :undoc-members:
    :inherited-members:

.. autoclass:: findiff.Identity
    :members:
    :undoc-members:
